==> jc-1.4.0.tar.gz: javax/rmi/BAD__5fOPERATION.h <==
// public class javax.rmi.BAD_OPERATION

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 61b181df0f842ae4 javax_rmi_BAD__5fOPERATION

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_rmi_BAD__5fOPERATION_H_
#define _JC_javax_rmi_BAD__5fOPERATION_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_rmi_BAD__5fOPERATION$sub_refs	_jc_javax_rmi_BAD__5fOPERATION$sub_refs;
typedef struct _jc_javax_rmi_BAD__5fOPERATION$sub_nonrefs	_jc_javax_rmi_BAD__5fOPERATION$sub_nonrefs;
typedef struct _jc_javax_rmi_BAD__5fOPERATION$refs	_jc_javax_rmi_BAD__5fOPERATION$refs;
typedef struct _jc_javax_rmi_BAD__5fOPERATION$nonrefs	_jc_javax_rmi_BAD__5fOPERATION$nonrefs;
typedef struct _jc_javax_rmi_BAD__5fOPERATION$object	_jc_javax_rmi_BAD__5fOPERATION$object;

typedef const struct _jc_javax_rmi_BAD__5fOPERATION$vmethods	_jc_javax_rmi_BAD__5fOPERATION$vmethods;
typedef const struct _jc_javax_rmi_BAD__5fOPERATION$vtable	_jc_javax_rmi_BAD__5fOPERATION$vtable;
typedef const struct _jc_javax_rmi_BAD__5fOPERATION$vtype	_jc_javax_rmi_BAD__5fOPERATION$vtype;

// Constructors
extern void _jc_javax_rmi_BAD__5fOPERATION$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_BAD__5fOPERATION$object *);

// Virtual methods structure
struct _jc_javax_rmi_BAD__5fOPERATION$vmethods {
};

// Vtable
struct _jc_javax_rmi_BAD__5fOPERATION$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_rmi_BAD__5fOPERATION$vmethods	javax_rmi_BAD__5fOPERATION;
};

// Vtype
struct _jc_javax_rmi_BAD__5fOPERATION$vtype {
	_jc_type			type;
	_jc_javax_rmi_BAD__5fOPERATION$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_BAD__5fOPERATION$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_BAD__5fOPERATION$refs {
    _jc_javax_rmi_BAD__5fOPERATION$sub_refs	javax_rmi_BAD__5fOPERATION;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_BAD__5fOPERATION$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_BAD__5fOPERATION$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_rmi_BAD__5fOPERATION$sub_nonrefs	javax_rmi_BAD__5fOPERATION;
};

// Object instance structure
struct _jc_javax_rmi_BAD__5fOPERATION$object {
	_jc_javax_rmi_BAD__5fOPERATION$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_BAD__5fOPERATION$vtype	*vtype;
	_jc_javax_rmi_BAD__5fOPERATION$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_BAD__5fOPERATION$vtype _jc_javax_rmi_BAD__5fOPERATION$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_BAD__5fOPERATION, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_BAD__5fOPERATION$class_object;

#endif	/* _JC_javax_rmi_BAD__5fOPERATION_H_ */

==> jc-1.4.6.tar.gz: javax/rmi/BAD__5fOPERATION.h <==
// public class javax.rmi.BAD_OPERATION

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 61b181df0f842ae4 javax_rmi_BAD__5fOPERATION

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_rmi_BAD__5fOPERATION_H_
#define _JC_javax_rmi_BAD__5fOPERATION_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_rmi_BAD__5fOPERATION$sub_refs	_jc_javax_rmi_BAD__5fOPERATION$sub_refs;
typedef struct _jc_javax_rmi_BAD__5fOPERATION$sub_nonrefs	_jc_javax_rmi_BAD__5fOPERATION$sub_nonrefs;
typedef struct _jc_javax_rmi_BAD__5fOPERATION$refs	_jc_javax_rmi_BAD__5fOPERATION$refs;
typedef struct _jc_javax_rmi_BAD__5fOPERATION$nonrefs	_jc_javax_rmi_BAD__5fOPERATION$nonrefs;
typedef struct _jc_javax_rmi_BAD__5fOPERATION$object	_jc_javax_rmi_BAD__5fOPERATION$object;

typedef const struct _jc_javax_rmi_BAD__5fOPERATION$vmethods	_jc_javax_rmi_BAD__5fOPERATION$vmethods;
typedef const struct _jc_javax_rmi_BAD__5fOPERATION$vtable	_jc_javax_rmi_BAD__5fOPERATION$vtable;
typedef const struct _jc_javax_rmi_BAD__5fOPERATION$vtype	_jc_javax_rmi_BAD__5fOPERATION$vtype;

// Constructors
extern void _jc_javax_rmi_BAD__5fOPERATION$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_BAD__5fOPERATION$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_rmi_BAD__5fOPERATION$vmethods {
};

// Vtable
struct _jc_javax_rmi_BAD__5fOPERATION$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_rmi_BAD__5fOPERATION$vmethods	javax_rmi_BAD__5fOPERATION;
};

// Vtype
struct _jc_javax_rmi_BAD__5fOPERATION$vtype {
	_jc_type			type;
	_jc_javax_rmi_BAD__5fOPERATION$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_BAD__5fOPERATION$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_BAD__5fOPERATION$refs {
    _jc_javax_rmi_BAD__5fOPERATION$sub_refs	javax_rmi_BAD__5fOPERATION;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_BAD__5fOPERATION$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_BAD__5fOPERATION$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_rmi_BAD__5fOPERATION$sub_nonrefs	javax_rmi_BAD__5fOPERATION;
};

// Object instance structure
struct _jc_javax_rmi_BAD__5fOPERATION$object {
	_jc_javax_rmi_BAD__5fOPERATION$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_BAD__5fOPERATION$vtype	*vtype;
	_jc_javax_rmi_BAD__5fOPERATION$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_BAD__5fOPERATION$vtype _jc_javax_rmi_BAD__5fOPERATION$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_BAD__5fOPERATION, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_BAD__5fOPERATION$class_object;

#endif	/* _JC_javax_rmi_BAD__5fOPERATION_H_ */
